@@ -18,7 +18,7 @@ class BertHTTPProxy(Process):
         from transformer_serving.client import ConcurrentBertClient
 
         app = FastAPI()
-        logger = set_logger(colored('PROXY', 'red'))
+        logger = set_logger(colored('PROXY', 'red'), args.verbose)
 
         # support up to 10 concurrent HTTP requests
         bc = ConcurrentBertClient(max_concurrency=self.args.http_max_connect,
